/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

        Authors:    Domas Mituzas, Facebook ( domas at fb dot com )
                    Mark Leith, Oracle Corporation (mark dot leith at oracle dot com)
                    Andrew Hutchings, MariaDB Foundation (andrew at mariadb dot org)
                    Max Bubenick, Percona RDBA (max dot bubenick at percona dot com)
                    David Ducos, Percona (david dot ducos at percona dot com)
*/
#define INSERT_ARG "INSERT"
#define LOAD_DATA_ARG "LOAD_DATA"
#define CSV_ARG "CSV"
#define CLICKHOUSE_ARG "CLICKHOUSE"
#define SQL_INSERT 0
#define LOAD_DATA 1
#define CSV 2
#define CLICKHOUSE 3
#define SQL "sql"
#define DAT "dat"
#define MEMORY "MEMORY"
GOptionContext * load_contex_entries();
